@@ -53,23 +53,17 @@ public:
 
     AttachmentModel *const q;
     AttachmentPart::List parts;
-    bool modified;
-    bool encryptEnabled;
-    bool signEnabled;
-    bool encryptSelected;
-    bool signSelected;
-    bool autoDisplayEnabled;
+    bool modified = false;
+    bool encryptEnabled = false;
+    bool signEnabled = false;
+    bool encryptSelected = false;
+    bool signSelected = false;
+    bool autoDisplayEnabled = false;
     QList<QTemporaryDir *> tempDirs;
 };
 
 AttachmentModel::Private::Private(AttachmentModel *qq)
     : q(qq)
-    , modified(false)
-    , encryptEnabled(false)
-    , signEnabled(false)
-    , encryptSelected(false)
-    , signSelected(false)
-    , autoDisplayEnabled(false)
 {
 }
 
@@ -83,17 +77,6 @@ AttachmentModel::AttachmentModel(QObject *parent)
     : QAbstractItemModel(parent)
     , d(new Private(this))
 {
-    QHash<int, QByteArray> names = roleNames();
-    names.insert(NameRole, "attachmentName");
-    names.insert(SizeRole, "attachmentSize");
-    names.insert(EncodingRole, "attachmentEncoding");
-    names.insert(MimeTypeRole, "attachmentMimeType");
-    names.insert(CompressRole, "attachmentIsCompressed");
-    names.insert(EncryptRole, "attachmentIsEncrypted");
-    names.insert(SignRole, "attachmentIsSigned");
-    names.insert(AutoDisplayRole, "attachmentIsAutoDiplayed");
-
-    setRoleNames(names);
 }
 
 AttachmentModel::~AttachmentModel()
@@ -101,8 +84,7 @@ AttachmentModel::~AttachmentModel()
     delete d;
 }
 
-bool AttachmentModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
-                                   int row, int column, const QModelIndex &parent)
+bool AttachmentModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent)
 {
     Q_UNUSED(row);
     Q_UNUSED(column);
@@ -288,7 +270,7 @@ QVariant AttachmentModel::data(const QModelIndex &index, int role) const
         default:
             return QVariant();
         }
-    } else if( role == Qt::ToolTipRole ) {
+    } else if (role == Qt::ToolTipRole) {
         return QVariant::fromValue(
             i18nc("@info:tooltip",
                   "Name: %1<br>Size: %2<br>Encoding: %3<br>MimeType=%4",
@@ -342,9 +324,22 @@ bool AttachmentModel::setData(const QModelIndex &index, const QVariant &value, i
     bool emitDataChanged = true;
     AttachmentPart::Ptr part = d->parts[ index.row() ];
 
-    if (role == Qt::CheckStateRole) {
+    if (role == Qt::EditRole) {
         switch (index.column()) {
-        case CompressColumn: {
+        case NameColumn:
+            if (!value.toString().isEmpty()) {
+                part->setName(value.toString());
+            } else {
+                return false;
+            }
+            break;
+        default:
+            return false;
+        }
+    } else if (role == Qt::CheckStateRole) {
+        switch (index.column()) {
+        case CompressColumn:
+        {
             bool toZip = value.toBool();
             if (toZip != part->isCompressed()) {
                 Q_EMIT attachmentCompressRequested(part, toZip);
@@ -363,7 +358,7 @@ bool AttachmentModel::setData(const QModelIndex &index, const QVariant &value, i
             break;
         default:
             break; // Do nothing.
-        };
+        }
     } else {
         return false;
     }
@@ -439,11 +434,13 @@ Qt::ItemFlags AttachmentModel::flags(const QModelIndex &index) const
         return Qt::ItemIsDropEnabled | defaultFlags;
     }
 
-    if (index.column() == CompressColumn ||
-            index.column() == EncryptColumn ||
-            index.column() == SignColumn ||
-            index.column() == AutoDisplayColumn) {
+    if (index.column() == CompressColumn
+        || index.column() == EncryptColumn
+        || index.column() == SignColumn
+        || index.column() == AutoDisplayColumn) {
         return Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled | Qt::ItemIsUserCheckable | defaultFlags;
+    } else if (index.column() == NameColumn) {
+        return Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled | Qt::ItemIsEditable | defaultFlags;
     } else {
         return Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled | defaultFlags;
     }
@@ -475,7 +472,7 @@ QVariant AttachmentModel::headerData(int section, Qt::Orientation orientation, i
     default:
         qCWarning(MESSAGECOMPOSER_LOG) << "Bad column" << section;
         return QVariant();
-    };
+    }
 }
 
 QModelIndex AttachmentModel::index(int row, int column, const QModelIndex &parent) const
