@@ -23,24 +23,9 @@
 
 using namespace MessageComposer;
 
-class RecipientsEditorManagerPrivate
-{
-public:
-    RecipientsEditorManagerPrivate()
-        : manager(new RecipientsEditorManager)
-    {
-
-    }
-    RecipientsEditorManager *manager;
-};
-
-Q_GLOBAL_STATIC(RecipientsEditorManagerPrivate, sInstance)
-
 RecipientsEditorManager::RecipientsEditorManager(QObject *parent)
-    : QObject(parent),
-      mModel(nullptr)
+    : QObject(parent)
 {
-
 }
 
 RecipientsEditorManager::~RecipientsEditorManager()
@@ -49,7 +34,8 @@ RecipientsEditorManager::~RecipientsEditorManager()
 
 RecipientsEditorManager *RecipientsEditorManager::self()
 {
-    return sInstance->manager;
+    static RecipientsEditorManager s_self;
+    return &s_self;
 }
 
 Akonadi::EmailAddressSelectionModel *RecipientsEditorManager::model()
