@@ -20,18 +20,14 @@
 #define MESSAGELISTUTIL_H
 
 #include <messagelist_export.h>
-#include <QObject>
 #include <QString>
 #include <QColor>
 
-namespace Akonadi
-{
+namespace Akonadi {
 class Item;
 }
-namespace MessageList
-{
-namespace Util
-{
+namespace MessageList {
+namespace Util {
 MESSAGELIST_EXPORT void deleteConfig(const QString &collectionId);
 MESSAGELIST_EXPORT QColor unreadDefaultMessageColor();
 MESSAGELIST_EXPORT QColor importantDefaultMessageColor();
@@ -42,4 +38,3 @@ MESSAGELIST_EXPORT QString contentSummary(const Akonadi::Item &item);
 }
 
 #endif /* MESSAGELISTUTIL_H */
-
