@@ -65,7 +65,8 @@ using namespace MessageList::Core;
 static const char gThemeContentItemTypeDndMimeDataFormat[] = "application/x-kmail-messagelistview-theme-contentitem-type";
 
 ThemeColumnPropertiesDialog::ThemeColumnPropertiesDialog(QWidget *parent, Theme::Column *column, const QString &title)
-    : QDialog(parent), mColumn(column)
+    : QDialog(parent)
+    , mColumn(column)
 {
     setWindowModality(Qt::ApplicationModal);   // FIXME: Sure ?
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -82,9 +83,7 @@ ThemeColumnPropertiesDialog::ThemeColumnPropertiesDialog(QWidget *parent, Theme:
 
     QGridLayout *g = new QGridLayout(base);
 
-    QLabel *l;
-
-    l = new QLabel(i18nc("@label:textbox Property name", "Name:"), base);
+    QLabel *l = new QLabel(i18nc("@label:textbox Property name", "Name:"), base);
     g->addWidget(l, 0, 0);
 
     mNameEdit = new KLineEdit(base);
@@ -117,7 +116,6 @@ ThemeColumnPropertiesDialog::ThemeColumnPropertiesDialog(QWidget *parent, Theme:
     mIsSenderOrReceiverCheck->setChecked(mColumn->isSenderOrReceiver());
     ComboBoxUtils::fillIntegerOptionCombo(mMessageSortingCombo, SortOrder::enumerateMessageSortingOptions(Aggregation::PerfectReferencesAndSubject));
     ComboBoxUtils::setIntegerOptionComboValue(mMessageSortingCombo, mColumn->messageSorting());
-
 }
 
 void ThemeColumnPropertiesDialog::slotOkButtonClicked()
@@ -132,14 +130,15 @@ void ThemeColumnPropertiesDialog::slotOkButtonClicked()
     mColumn->setMessageSorting(
         static_cast< SortOrder::MessageSorting >(
             ComboBoxUtils::getIntegerOptionComboValue(mMessageSortingCombo, SortOrder::NoMessageSorting)
-        )
-    );
+            )
+        );
 
     accept();
 }
 
 ThemeContentItemSourceLabel::ThemeContentItemSourceLabel(QWidget *parent, Theme::ContentItem::Type type)
-    : QLabel(parent), mType(type)
+    : QLabel(parent)
+    , mType(type)
 {
     setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
 }
@@ -179,7 +178,7 @@ void ThemeContentItemSourceLabel::startDrag()
     QMimeData *data = new QMimeData();
     QByteArray arry;
     arry.resize(sizeof(Theme::ContentItem::Type));
-    *((Theme::ContentItem::Type *) arry.data()) = mType;
+    *((Theme::ContentItem::Type *)arry.data()) = mType;
     data->setData(QLatin1String(gThemeContentItemTypeDndMimeDataFormat), arry);
     QDrag *drag = new QDrag(this);
     drag->setMimeData(data);
@@ -251,8 +250,8 @@ Item *ThemePreviewDelegate::itemFromIndex(const QModelIndex &index) const
 }
 
 ThemePreviewWidget::ThemePreviewWidget(QWidget *parent)
-    : QTreeWidget(parent),
-      mTheme(nullptr)
+    : QTreeWidget(parent)
+    , mTheme(nullptr)
 {
     mSelectedThemeContentItem = nullptr;
     mSelectedThemeColumn = nullptr;
@@ -276,7 +275,7 @@ ThemePreviewWidget::ThemePreviewWidget(QWidget *parent)
     m->setText(0, QString());
 
     mGroupHeaderSampleItem->setExpanded(true);
-    header()->setMovable(false);
+    header()->setSectionsMovable(false);
 }
 
 void ThemePreviewWidget::changeEvent(QEvent *event)
@@ -503,7 +502,7 @@ void ThemePreviewWidget::internalHandleDragMoveEvent(QDragMoveEvent *e)
         return;    // ugh
     }
 
-    Theme::ContentItem::Type type = *((Theme::ContentItem::Type *) arry.data());
+    Theme::ContentItem::Type type = *((Theme::ContentItem::Type *)arry.data());
 
     if (!computeContentItemInsertPosition(e->pos(), type)) {
         return;
@@ -549,7 +548,7 @@ void ThemePreviewWidget::dropEvent(QDropEvent *e)
         return;    // ugh
     }
 
-    Theme::ContentItem::Type type = *((Theme::ContentItem::Type *) arry.data());
+    Theme::ContentItem::Type type = *((Theme::ContentItem::Type *)arry.data());
 
     if (!computeContentItemInsertPosition(e->pos(), type)) {
         viewport()->update();
@@ -602,9 +601,9 @@ void ThemePreviewWidget::dropEvent(QDropEvent *e)
             delete ci;
             return;
         }
-        idx = mDelegate->hitContentItemRight() ? \
-              row->rightItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem())) : \
-              row->leftItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem()));
+        idx = mDelegate->hitContentItemRight()   \
+              ? row->rightItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem()))   \
+              : row->leftItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem()));
         if (idx < 0) {
             // bleah
             delete ci;
@@ -622,9 +621,9 @@ void ThemePreviewWidget::dropEvent(QDropEvent *e)
             delete ci;
             return;
         }
-        idx = mDelegate->hitContentItemRight() ? \
-              row->rightItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem())) : \
-              row->leftItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem()));
+        idx = mDelegate->hitContentItemRight()   \
+              ? row->rightItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem()))   \
+              : row->leftItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem()));
         if (idx < 0) {
             // bleah
             delete ci;
@@ -719,11 +718,11 @@ bool ThemePreviewWidget::computeContentItemInsertPosition(const QPoint &pos, The
     if (!mDelegate->hitContentItem()) {
         // didn't hit anything... probably no items in the row
         if (pos.x() < (rowRect.left() + (rowRect.width() / 2))) {
-            mItemInsertPosition =  AsLastLeftItem;
+            mItemInsertPosition = AsLastLeftItem;
             mDropIndicatorPoint1 = QPoint(rowRect.left(), rowRect.top());
             mDropIndicatorPoint2 = QPoint(rowRect.left(), rowRect.bottom());
         } else {
-            mItemInsertPosition =  AsLastRightItem;
+            mItemInsertPosition = AsLastRightItem;
             mDropIndicatorPoint1 = QPoint(rowRect.right(), rowRect.top());
             mDropIndicatorPoint2 = QPoint(rowRect.right(), rowRect.bottom());
         }
@@ -810,7 +809,7 @@ void ThemePreviewWidget::mouseMoveEvent(QMouseEvent *e)
     QMimeData *data = new QMimeData();
     QByteArray arry;
     arry.resize(sizeof(Theme::ContentItem::Type));
-    *((Theme::ContentItem::Type *) arry.data()) = mSelectedThemeContentItem->type();
+    *((Theme::ContentItem::Type *)arry.data()) = mSelectedThemeContentItem->type();
     data->setData(QLatin1String(gThemeContentItemTypeDndMimeDataFormat), arry);
     QDrag *drag = new QDrag(this);
     drag->setMimeData(data);
@@ -872,12 +871,10 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
         QMenu menu;
 
         if (mSelectedThemeContentItem) {
-
             menu.addSection(Theme::ContentItem::description(mSelectedThemeContentItem->type()));
 
             if (mSelectedThemeContentItem->displaysText()) {
-                QAction *act;
-                act = menu.addAction(i18nc("@action:inmenu soften the text color", "Soften"));
+                QAction *act = menu.addAction(i18nc("@action:inmenu soften the text color", "Soften"));
                 act->setCheckable(true);
                 act->setChecked(mSelectedThemeContentItem->softenByBlending());
                 connect(act, &QAction::triggered, this, &ThemePreviewWidget::slotSoftenActionTriggered);
@@ -903,8 +900,7 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
 
                 QActionGroup *grp = new QActionGroup(childmenu);
 
-                QAction *act;
-                act = childmenu->addAction(i18nc("@action:inmenu Foreground color setting", "Default"));
+                QAction *act = childmenu->addAction(i18nc("@action:inmenu Foreground color setting", "Default"));
                 act->setData(QVariant(static_cast< int >(0)));
                 act->setCheckable(true);
                 act->setChecked(!mSelectedThemeContentItem->useCustomColor());
@@ -925,8 +921,7 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
 
                 QActionGroup *grp = new QActionGroup(childmenu);
 
-                QAction *act;
-                act = childmenu->addAction(i18nc("Hide a mark if the mail does not have the attribute, e.g. Important mark on a non important mail", "Hide"));
+                QAction *act = childmenu->addAction(i18nc("Hide a mark if the mail does not have the attribute, e.g. Important mark on a non important mail", "Hide"));
                 act->setData(QVariant(static_cast< int >(Theme::ContentItem::HideWhenDisabled)));
                 act->setCheckable(true);
                 act->setChecked(mSelectedThemeContentItem->hideWhenDisabled());
@@ -946,7 +941,6 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
 
                 menu.addMenu(childmenu)->setText(i18n("When Disabled"));
             }
-
         }
 
         if (mDelegate->hitItem()) {
@@ -958,8 +952,7 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
 
                 QActionGroup *grp = new QActionGroup(childmenu);
 
-                QAction *act;
-                act = childmenu->addAction(i18nc("@action:inmenu Group header background color setting", "None"));
+                QAction *act = childmenu->addAction(i18nc("@action:inmenu Group header background color setting", "None"));
                 act->setData(QVariant(static_cast< int >(Theme::Transparent)));
                 act->setCheckable(true);
                 act->setChecked(mTheme->groupHeaderBackgroundMode() == Theme::Transparent);
@@ -1001,7 +994,6 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
                 if (mTheme->groupHeaderBackgroundMode() == Theme::Transparent) {
                     act->setEnabled(false);
                 }
-
             }
         }
 
@@ -1010,7 +1002,6 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
         }
 
         menu.exec(viewport()->mapToGlobal(e->pos()));
-
     }
 }
 
@@ -1108,7 +1099,8 @@ void ThemePreviewWidget::slotGroupHeaderBackgroundModeMenuTriggered(QAction *act
     case Theme::AutoColor:
         mTheme->setGroupHeaderBackgroundMode(Theme::AutoColor);
         break;
-    case Theme::CustomColor: {
+    case Theme::CustomColor:
+    {
         QColor clr;
         clr = QColorDialog::getColor(mTheme->groupHeaderBackgroundColor(), this);
         if (!clr.isValid()) {
@@ -1117,8 +1109,8 @@ void ThemePreviewWidget::slotGroupHeaderBackgroundModeMenuTriggered(QAction *act
 
         mTheme->setGroupHeaderBackgroundMode(Theme::CustomColor);
         mTheme->setGroupHeaderBackgroundColor(clr);
+        break;
     }
-    break;
     }
 
     setTheme(mTheme);   // this will reset theme cache and trigger a global update
@@ -1142,9 +1134,9 @@ void ThemePreviewWidget::paintEvent(QPaintEvent *e)
     QTreeWidget::paintEvent(e);
 
     if (
-        mThemeSelectedContentItemRect.isValid() ||
-        (mDropIndicatorPoint1 != mDropIndicatorPoint2)
-    ) {
+        mThemeSelectedContentItemRect.isValid()
+        || (mDropIndicatorPoint1 != mDropIndicatorPoint2)
+        ) {
         QPainter painter(viewport());
 
         if (mThemeSelectedContentItemRect.isValid()) {
@@ -1188,9 +1180,7 @@ void ThemePreviewWidget::slotHeaderContextMenuRequested(const QPoint &pos)
 
     menu.setTitle(mSelectedThemeColumn->label());
 
-    QAction *act;
-
-    act = menu.addAction(i18n("Column Properties..."));
+    QAction *act = menu.addAction(i18n("Column Properties..."));
     connect(act, &QAction::triggered, this, &ThemePreviewWidget::slotColumnProperties);
 
     act = menu.addAction(i18n("Add Column..."));
@@ -1255,8 +1245,8 @@ void ThemePreviewWidget::slotAddColumn()
     mSelectedThemeColumn->addMessageRow(new Theme::Row());
     mSelectedThemeColumn->addGroupHeaderRow(new Theme::Row());
 
-    ThemeColumnPropertiesDialog *dlg =
-        new ThemeColumnPropertiesDialog(this, mSelectedThemeColumn, i18n("Add New Column"));
+    ThemeColumnPropertiesDialog *dlg
+        = new ThemeColumnPropertiesDialog(this, mSelectedThemeColumn, i18n("Add New Column"));
 
     if (dlg->exec() == QDialog::Accepted) {
         mTheme->insertColumn(newColumnIndex, mSelectedThemeColumn);
@@ -1266,9 +1256,7 @@ void ThemePreviewWidget::slotAddColumn()
         mDropIndicatorPoint1 = mDropIndicatorPoint2;
 
         setTheme(mTheme);   // this will reset theme cache and trigger a global update
-
     } else {
-
         delete mSelectedThemeColumn;
         mSelectedThemeColumn = nullptr;
     }
@@ -1282,8 +1270,8 @@ void ThemePreviewWidget::slotColumnProperties()
         return;
     }
 
-    ThemeColumnPropertiesDialog *dlg =
-        new ThemeColumnPropertiesDialog(this, mSelectedThemeColumn, i18n("Column Properties"));
+    ThemeColumnPropertiesDialog *dlg
+        = new ThemeColumnPropertiesDialog(this, mSelectedThemeColumn, i18n("Column Properties"));
 
     if (dlg->exec() == QDialog::Accepted) {
         mSelectedThemeContentItem = nullptr;
@@ -1455,7 +1443,8 @@ ThemeEditor::ThemeEditor(QWidget *parent)
     tabg->addWidget(mPreviewWidget, 1, 0);
 
     QLabel *l = new QLabel(tab);
-    l->setText(i18n("Right click on the header to add or modify columns. Drag the content items and drop them on the columns in order to compose your theme. Right click on the items inside the view for more options."));
+    l->setText(i18n(
+                   "Right click on the header to add or modify columns. Drag the content items and drop them on the columns in order to compose your theme. Right click on the items inside the view for more options."));
     l->setWordWrap(true);
     l->setAlignment(Qt::AlignCenter);
     tabg->addWidget(l, 2, 0);
@@ -1489,7 +1478,6 @@ ThemeEditor::ThemeEditor(QWidget *parent)
     tabg->setColumnStretch(1, 1);
     tabg->setRowStretch(2, 1);
     fillViewHeaderPolicyCombo();
-
 }
 
 ThemeEditor::~ThemeEditor()
@@ -1535,7 +1523,7 @@ void ThemeEditor::commit()
 
     mCurrentTheme->setViewHeaderPolicy(
         (Theme::ViewHeaderPolicy)ComboBoxUtils::getIntegerOptionComboValue(mViewHeaderPolicyCombo, 0)
-    );
+        );
     mCurrentTheme->setIconSize(mIconSizeSpinBox->value());
     // other settings are already committed to this theme
 }
@@ -1545,7 +1533,7 @@ void ThemeEditor::fillViewHeaderPolicyCombo()
     ComboBoxUtils::fillIntegerOptionCombo(
         mViewHeaderPolicyCombo,
         Theme::enumerateViewHeaderPolicyOptions()
-    );
+        );
 }
 
 void ThemeEditor::slotNameEditTextEdited(const QString &newName)
@@ -1571,4 +1559,3 @@ MessageList::Core::Theme *ThemeEditor::editedTheme() const
 {
     return mCurrentTheme;
 }
-
