@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,8 +25,7 @@
 #include <QObject>
 class KActionMenu;
 class KActionCollection;
-namespace MessageViewer
-{
+namespace MessageViewer {
 class HeaderStylePlugin;
 class HeaderStyleMenuManagerPrivate;
 class MESSAGEVIEWER_EXPORT HeaderStyleMenuManager : public QObject
