@@ -50,9 +50,8 @@ void RenderTest::testRenderSmart_data()
     QTest::addColumn<QString>("asyncFileName");
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
-    foreach (const QString &file,
-             dir.entryList(QStringList(QLatin1String("*.mbox")),
-                           QDir::Files | QDir::Readable | QDir::NoSymLinks)) {
+    const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
+    foreach (const QString &file, l) {
         if (!QFile::exists(dir.path() + QLatin1Char('/') + file + QStringLiteral(".html"))) {
             continue;
         }
@@ -79,10 +78,8 @@ void RenderTest::testRenderSmartAsync_data()
     QTest::addColumn<QString>("asyncFileName");
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
-
-    foreach (const QString &file,
-             dir.entryList(QStringList(QLatin1String("*.mbox")),
-                           QDir::Files | QDir::Readable | QDir::NoSymLinks)) {
+    const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
+    foreach (const QString &file, l) {
         if (!QFile::exists(dir.path() + QLatin1Char('/') + file
                            + QStringLiteral(".inProgress.html"))) {
             continue;
@@ -113,9 +110,8 @@ void RenderTest::testRenderSmartDetails_data()
     QTest::addColumn<QString>("asyncFileName");
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
-    foreach (const QString &file,
-             dir.entryList(QStringList(QLatin1String("*.mbox")),
-                           QDir::Files | QDir::Readable | QDir::NoSymLinks)) {
+    const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
+    foreach (const QString &file, l) {
         QString fname = dir.path() + QStringLiteral("/details/") + file + QStringLiteral(".html");
         if (!QFile::exists(fname)) {
             continue;
@@ -141,9 +137,8 @@ void RenderTest::testRenderInlined_data()
     QTest::addColumn<QString>("asyncFileName");
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
-    foreach (const QString &file,
-             dir.entryList(QStringList(QLatin1String("*.mbox")),
-                           QDir::Files | QDir::Readable | QDir::NoSymLinks)) {
+    const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
+    foreach (const QString &file, l) {
         QString fname = dir.path() + QStringLiteral("/inlined/") + file + QStringLiteral(".html");
         if (!QFile::exists(fname)) {
             fname = dir.path() + QStringLiteral("/") + file + QStringLiteral(".html");
@@ -173,9 +168,8 @@ void RenderTest::testRenderIconic_data()
     QTest::addColumn<QString>("asyncFileName");
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
-    foreach (const QString &file,
-             dir.entryList(QStringList(QLatin1String("*.mbox")),
-                           QDir::Files | QDir::Readable | QDir::NoSymLinks)) {
+    const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
+    foreach (const QString &file, l) {
         QString fname = dir.path() + QStringLiteral("/iconic/") + file + QStringLiteral(".html");
         if (!QFile::exists(fname)) {
             fname = dir.path() + QStringLiteral("/") + file + QStringLiteral(".html");
@@ -205,9 +199,8 @@ void RenderTest::testRenderHidden_data()
     QTest::addColumn<QString>("asyncFileName");
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
-    foreach (const QString &file,
-             dir.entryList(QStringList(QLatin1String("*.mbox")),
-                           QDir::Files | QDir::Readable | QDir::NoSymLinks)) {
+    const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
+    foreach (const QString &file, l) {
         QString fname = dir.path() + QStringLiteral("/hidden/") + file + QStringLiteral(".html");
         if (!QFile::exists(fname)) {
             fname = dir.path() + QStringLiteral("/") + file + QStringLiteral(".html");
@@ -237,9 +230,8 @@ void RenderTest::testRenderHeaderOnly_data()
     QTest::addColumn<QString>("asyncFileName");
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
-    foreach (const QString &file,
-             dir.entryList(QStringList(QLatin1String("*.mbox")),
-                           QDir::Files | QDir::Readable | QDir::NoSymLinks)) {
+    const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
+    foreach (const QString &file, l) {
         QString fname = dir.path() + QStringLiteral("/headeronly/") + file
                         + QStringLiteral(".html");
         if (!QFile::exists(fname)) {
@@ -260,8 +252,7 @@ void RenderTest::testRenderHeaderOnly()
     testRender();
 }
 
-QString renderTreeHelper(const MimeTreeParser::Interface::MessagePart::Ptr &messagePart,
-                         QString indent)
+QString renderTreeHelper(const MimeTreeParser::MessagePart::Ptr &messagePart, QString indent)
 {
     const QString line
         = QStringLiteral("%1 * %3\n").arg(indent,
@@ -269,11 +260,8 @@ QString renderTreeHelper(const MimeTreeParser::Interface::MessagePart::Ptr &mess
     QString ret = line;
 
     indent += QStringLiteral(" ");
-    const auto m = messagePart.dynamicCast<MimeTreeParser::MessagePart>();
-    if (m) {
-        foreach (const auto &subPart, m->subParts()) {
-            ret += renderTreeHelper(subPart, indent);
-        }
+    foreach (const auto &subPart, messagePart->subParts()) {
+        ret += renderTreeHelper(subPart, indent);
     }
     return ret;
 }
@@ -337,95 +325,34 @@ void RenderTest::testRender()
     connect(&nodeHelper, &MimeTreeParser::NodeHelper::update, &loop, &QEventLoop::quit);
     otp.setAllowAsync(bAsync);
 
-    fileWriter.begin(QString());
-    fileWriter.queue(cssHelper.htmlHead(false));
+    fileWriter.begin();
+    fileWriter.write(cssHelper.htmlHead(false));
 
     otp.parseObjectTree(msg.data());
 
-    fileWriter.queue(QStringLiteral("</body></html>"));
-    fileWriter.flush();
+    fileWriter.write(QStringLiteral("</body></html>"));
     fileWriter.end();
 
     if (!bAsync) {
         testRenderTree(otp.parsedPart());
     } else {
-        compareFile(outFileName, asyncFileName);
+        Test::compareFile(outFileName, asyncFileName);
         loop.exec();
 
         MimeTreeParser::ObjectTreeParser otp(&testSource, &nodeHelper);
         otp.setAllowAsync(bAsync);
 
-        fileWriter.begin(QString());
-        fileWriter.queue(cssHelper.htmlHead(false));
+        fileWriter.begin();
+        fileWriter.write(cssHelper.htmlHead(false));
 
         otp.parseObjectTree(msg.data());
 
-        fileWriter.queue(QStringLiteral("</body></html>"));
-        fileWriter.flush();
+        fileWriter.write(QStringLiteral("</body></html>"));
         fileWriter.end();
 
         testRenderTree(otp.parsedPart());
     }
-    compareFile(outFileName, referenceFileName);
-}
-
-void RenderTest::compareFile(const QString &outFile, const QString &referenceFile)
-{
-    QVERIFY(QFile::exists(outFile));
-
-    const QString htmlFile = outFile + QStringLiteral(".html");
-    // remove tailing newlines and spaces and make htmlmore uniform (breaks pre tags)
-    {
-        QFile f(outFile);
-        QVERIFY(f.open(QIODevice::ReadOnly));
-        QString content = QString::fromUtf8(f.readAll());
-        f.close();
-        content.replace(QRegExp(QStringLiteral("[\t ]+")), QStringLiteral(" "));
-        content.replace(QRegExp(QStringLiteral("[\t ]*\n+[\t ]*")), QStringLiteral("\n"));
-        content.replace(QRegExp(QStringLiteral("([\n\t ])\\1+")), QStringLiteral("\\1"));
-        content.replace(QRegExp(QStringLiteral(">\n+[\t ]*")), QStringLiteral(">"));
-        content.replace(QRegExp(QStringLiteral("[\t ]*\n+[\t ]*<")), QStringLiteral("<"));
-        QVERIFY(f.open(QIODevice::WriteOnly | QIODevice::Truncate));
-        f.write(content.toUtf8());
-        f.close();
-    }
-
-    // validate xml and pretty-print for comparisson
-    // TODO add proper cmake check for xmllint and diff
-    QStringList args = QStringList()
-                       << QStringLiteral("--format")
-                       << QStringLiteral("--encode")
-                       << QStringLiteral("UTF8")
-                       << QStringLiteral("--output")
-                       << htmlFile
-                       << outFile;
-    QCOMPARE(QProcess::execute(QStringLiteral("xmllint"), args), 0);
-
-    // get rid of system dependent or random paths
-    {
-        QFile f(htmlFile);
-        QVERIFY(f.open(QIODevice::ReadOnly));
-        QString content = QString::fromUtf8(f.readAll());
-        f.close();
-        content.replace(QRegExp(QStringLiteral(
-                                    "\"file:[^\"]*[/(?:%2F)]([^\"/(?:%2F)]*)\"")),
-                        QStringLiteral("\"file:\\1\""));
-        QVERIFY(f.open(QIODevice::WriteOnly | QIODevice::Truncate));
-        f.write(content.toUtf8());
-        f.close();
-    }
-
-    // compare to reference file
-    args = QStringList()
-           << QStringLiteral("-u")
-           << referenceFile
-           << htmlFile;
-    QProcess proc;
-    proc.setProcessChannelMode(QProcess::ForwardedChannels);
-    proc.start(QStringLiteral("diff"), args);
-    QVERIFY(proc.waitForFinished());
-
-    QCOMPARE(proc.exitCode(), 0);
+    Test::compareFile(outFileName, referenceFileName);
 }
 
 QTEST_MAIN(RenderTest)
