@@ -19,6 +19,7 @@
 */
 
 #include "setupenv.h"
+#include "messagepartthemes/default/messagepartrendererfactory.h"
 
 #include <QStandardPaths>
 
@@ -31,7 +32,11 @@ void MessageViewer::Test::setupEnv()
 {
     setenv("KDEHOME", QFile::encodeName(QDir::homePath() + QString::fromLatin1(
                                             "/.qttest")).constData(), 1);
+    setenv("TZ", "UTC", 1);
     QStandardPaths::setTestModeEnabled(true);
     QIcon::setThemeName(QStringLiteral("breeze"));
     QLocale::setDefault(QLocale(QStringLiteral("en_US")));
+
+    // disable plugin loading, so kdepim-addons doesn't interfere with our tests
+    MessagePartRendererFactory::instance()->setPluginPath(QString());
 }
