@@ -22,8 +22,7 @@
 
 #include <messageviewer/headerstrategy.h>
 
-namespace MessageViewer
-{
+namespace MessageViewer {
 class DefaultGrantleeHeaderStrategy : public HeaderStrategy
 {
 public:
@@ -31,11 +30,12 @@ public:
     ~DefaultGrantleeHeaderStrategy();
 
 public:
-    const char *name() const Q_DECL_OVERRIDE
+    const char *name() const override
     {
         return "defaultgrantlee";
     }
-    DefaultPolicy defaultPolicy() const Q_DECL_OVERRIDE
+
+    DefaultPolicy defaultPolicy() const override
     {
         return Hide;
     }
