@@ -37,8 +37,7 @@ public:
     bool decryptMessage() const override;
     bool htmlLoadExternal() const override;
     bool showSignatureDetails() const override;
-    void setHtmlMode(MimeTreeParser::Util::HtmlMode mode,
-                     const QList<MimeTreeParser::Util::HtmlMode> &availableModes) override;
+    void setHtmlMode(MimeTreeParser::Util::HtmlMode mode, const QList<MimeTreeParser::Util::HtmlMode> &availableModes) override;
     MimeTreeParser::Util::HtmlMode preferredMode() const override;
     void setAllowDecryption(bool allowDecryption);
     int levelQuote() const override;
@@ -51,9 +50,8 @@ public:
     bool autoImportKeys() const override;
     bool showEmoticons() const override;
     bool showExpandQuotesMark() const override;
-    const MimeTreeParser::BodyPartFormatterBaseFactory *bodyPartFormatterFactory() override;
-    MimeTreeParser::Interface::MessagePartRendererPtr messagePartTheme(
-        MimeTreeParser::Interface::MessagePartPtr msgPart) override;
+    const MimeTreeParser::BodyPartFormatterFactory *bodyPartFormatterFactory() override;
+    void render(const MimeTreeParser::MessagePartPtr &msgPart, MimeTreeParser::HtmlWriter *htmlWriter) override;
     bool isPrinting() const override;
 private:
     EmptySourcePrivate *const d;
