@@ -19,7 +19,6 @@
 
 #include "mailwebenginescript.h"
 #include "webengineviewer/webenginescript.h"
-#include <QDebug>
 using namespace MessageViewer;
 
 static QString checkJQuery(const char *scriptName)
@@ -71,8 +70,20 @@ QString MailWebEngineScript::manageShowHideAttachments(bool hide)
     return source;
 }
 
-QString MailWebEngineScript::injectAttachments(const QString &delayedHtml,
-                                               const QString &elementStr)
+QString MailWebEngineScript::manageShowHideEncryptionDetails(bool hide)
+{
+    QString source = checkJQuery("manageShowHideEncryptionDetails");
+    if (hide) {
+        source += QString::fromLatin1("qt.jQuery(\".enc-details\").hide();"
+                                      "qt.jQuery(\".enc-simple\").show();");
+    } else {
+        source += QString::fromLatin1("qt.jQuery('.enc-simple').hide();"
+                                      "qt.jQuery(\".enc-details\").show();");
+    }
+    return source;
+}
+
+QString MailWebEngineScript::injectAttachments(const QString &delayedHtml, const QString &elementStr)
 {
     const QString source = checkJQuery("injectAttachments") + QString::fromLatin1(
         "if (!document.getElementById('%1')) { console.warn('NOT FOUND: %1'); };\n"
