@@ -21,8 +21,8 @@
 
 #include "utils.h"
 
-#include "viewer/objecttreeparser.h"
-#include "viewer/messagepart.h"
+#include "objecttreeparser.h"
+#include "messagepart.h"
 
 #include <KMime/Content>
 
@@ -40,7 +40,7 @@ const Interface::BodyPartFormatter *MultiPartAlternativeBodyPartFormatter::creat
     return self;
 }
 
-Interface::MessagePart::Ptr MultiPartAlternativeBodyPartFormatter::process(Interface::BodyPart &part) const
+MessagePart::Ptr MultiPartAlternativeBodyPartFormatter::process(Interface::BodyPart &part) const
 {
     KMime::Content *node = part.content();
     if (node->contents().isEmpty()) {
@@ -67,8 +67,8 @@ Interface::MessagePart::Ptr MultiPartAlternativeBodyPartFormatter::process(Inter
             part.nodeHelper()->setNodeProcessed(dataPlain, false);
         }
         preferredMode = Util::MultipartIcal;
-    } else if ((dataHtml && (preferredMode == Util::MultipartHtml || preferredMode == Util::Html)) ||
-               (dataHtml && dataPlain && dataPlain->body().isEmpty())) {
+    } else if ((dataHtml && (preferredMode == Util::MultipartHtml || preferredMode == Util::Html))
+               || (dataHtml && dataPlain && dataPlain->body().isEmpty())) {
         if (dataPlain) {
             part.nodeHelper()->setNodeProcessed(dataPlain, false);
         }
