@@ -17,14 +17,16 @@
 
 #ifndef TEMPLATESTEXTEDITOR_H
 #define TEMPLATESTEXTEDITOR_H
+
 #include "kpimtextedit/plaintexteditor.h"
+
+#include <KSyntaxHighlighting/Repository>
+
 class QKeyEvent;
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class TextEditorCompleter;
 }
-namespace TemplateParser
-{
+namespace TemplateParser {
 class TemplatesTextEditor : public KPIMTextEdit::PlainTextEditor
 {
     Q_OBJECT
@@ -41,7 +43,8 @@ protected:
     void clearDecorator() override;
     void createHighlighter() override;
 private:
-    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter;
+    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter = nullptr;
+    KSyntaxHighlighting::Repository mSyntaxRepo;
 };
 }
 #endif // TEMPLATESTEXTEDITOR_H
