@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,7 +26,7 @@ class WebEngineAccessKeyAnchorTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit WebEngineAccessKeyAnchorTest(QObject *parent = Q_NULLPTR);
+    explicit WebEngineAccessKeyAnchorTest(QObject *parent = nullptr);
     ~WebEngineAccessKeyAnchorTest();
 private Q_SLOTS:
     void shouldReturnEmptyAccessKeyAnchor();
