@@ -18,7 +18,6 @@
 */
 
 #include "webengineexporthtmlpagejob.h"
-#include "webengineviewer/config-webengineviewer.h"
 #include <QTemporaryFile>
 #include <QWebEngineView>
 
@@ -41,14 +40,13 @@ InvokeWrapper<Arg, R, C> invoke(R *receiver, void (C::*memberFun)(Arg))
 }
 
 WebEngineExportHtmlPageJob::WebEngineExportHtmlPageJob(QObject *parent)
-    : QObject(parent),
-      mEngineView(nullptr)
+    : QObject(parent)
+    , mEngineView(nullptr)
 {
 }
 
 WebEngineExportHtmlPageJob::~WebEngineExportHtmlPageJob()
 {
-
 }
 
 void WebEngineExportHtmlPageJob::start()
