@@ -22,8 +22,7 @@
 
 #include <QWebEnginePage>
 
-namespace WebEngineViewer
-{
+namespace WebEngineViewer {
 class WebEnginePage;
 class WebEngineNavigationRequestInterceptor : public QWebEnginePage
 {
@@ -36,7 +35,7 @@ protected:
     bool acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame) override;
 
 private:
-    QWebEnginePage *mTargetPage;
+    QWebEnginePage *mTargetPage = nullptr;
 };
 }
 
